Displaying 19 results from an estimated 19 matches for "__unused5".
Did you mean:
__unused
2013 Nov 12
0
[klibc:master] arm64: Fix struct stat
...long st_mtime; /* Time of last modification. */
- unsigned long st_mtime_nsec;
- long st_ctime; /* Time of last status change. */
- unsigned long st_ctime_nsec;
- unsigned int __unused4;
- unsigned int __unused5;
- };
+ __stdev64 (st_dev); /* Device */
+ unsigned long st_ino; /* File serial number */
+ unsigned int st_mode; /* File mode */
+ unsigned int st_nlink; /* Link count */
+ unsigned int st_uid; /* User ID of the file's owner */
+ unsigned int st_gid; /* Group ID of the file's group */...
2005 Dec 28
0
[patch] sparc64 fix stat()
...off_t st_blksize;
+ off_t st_blocks;
time_t st_atime;
+ unsigned long __unused1;
time_t st_mtime;
+ unsigned long __unused2;
time_t st_ctime;
- off_t st_blksize;
- off_t st_blocks;
- unsigned long __unused4[2];
+ unsigned long __unused3;
+ unsigned long __unused4;
+ unsigned long __unused5;
};
#endif
2004 Sep 30
1
[don@donarmstrong.com: Bug#274301: libflac4 segfaults on corrupt flac files]
...st_nlink = 1, st_uid = 1000, st_gid = 1000, st_rdev = 0, __pad2 = 0,
st_size = 110592, st_blksize = 4096, st_blocks = 224, st_atim = {tv_sec = 1096585478, tv_nsec = 271352832}, st_mtim = {tv_sec = 1096585268,
tv_nsec = 0}, st_ctim = {tv_sec = 1096585340, tv_nsec = 284815843}, __unused4 = 0, __unused5 = 0}
i = 0
(gdb) info threads
* 1 process 8083 0x40205422 in FLAC__bitbuffer_read_rice_signed_block (bb=0x80601b8, vals=0x807dd80, nvals=4294967293, parameter=9,
read_callback=0x40220080 <read_callback_>, client_data=0x805ba58) at bitbuffer.c:2254
(gdb)
See http://rzlab.ucr.edu...
2004 Jun 04
3
illegal instruction
Skipped content of type multipart/alternative-------------- next part --------------
A non-text attachment was scrubbed...
Name: smime.p7s
Type: application/x-pkcs7-signature
Size: 1604 bytes
Desc: not available
Url : http://lists.digium.com/pipermail/asterisk-users/attachments/20040604/8bc355fd/smime.bin
2018 Jul 17
1
[PATCH klibc 1/2] rename, renameat: Use renameat2() system call
New architectures only define the renameat2() system call, which was
added in Linux 3.15. Define rename() and renameat() as wrappers for
it if necessary.
Signed-off-by: Ben Hutchings <ben at decadent.org.uk>
---
--- a/usr/klibc/Kbuild
+++ b/usr/klibc/Kbuild
@@ -59,7 +59,8 @@ klib-y += vsnprintf.o snprintf.o vsprint
inet/inet_ntoa.o inet/inet_aton.o inet/inet_addr.o \
2006 Jun 26
0
[klibc 31/43] ppc support for klibc
...*/
+
+ long long st_blocks; /* Number 512-byte blocks allocated. */
+ struct timespec st_atim; /* Time of last access. */
+ struct timespec st_mtim; /* Time of last modification. */
+ struct timespec st_ctim; /* Time of last status change. */
+ unsigned long int __unused4;
+ unsigned long int __unused5;
+};
+
+#endif
diff --git a/usr/include/arch/ppc64/klibc/archsys.h b/usr/include/arch/ppc64/klibc/archsys.h
new file mode 100644
index 0000000..e65d188
--- /dev/null
+++ b/usr/include/arch/ppc64/klibc/archsys.h
@@ -0,0 +1,52 @@
+/*
+ * arch/ppc64/include/klibc/archsys.h...
2013 Nov 12
0
[klibc:master] arm64: Add arm64 support
...long st_mtime; /* Time of last modification. */
+ unsigned long st_mtime_nsec;
+ long st_ctime; /* Time of last status change. */
+ unsigned long st_ctime_nsec;
+ unsigned int __unused4;
+ unsigned int __unused5;
+ };
+
+#endif
diff --git a/usr/include/arch/arm64/klibc/asmmacros.h b/usr/include/arch/arm64/klibc/asmmacros.h
new file mode 100644
index 0000000..c298f66
--- /dev/null
+++ b/usr/include/arch/arm64/klibc/asmmacros.h
@@ -0,0 +1,11 @@
+/*
+ * usr/include/arch/arm64/klibc/asmmacros.h
+ *
+ * Assemb...
2013 Nov 08
0
[PATCH 3/3] arm64: Introduce arm64 support
...long st_mtime; /* Time of last modification. */
+ unsigned long st_mtime_nsec;
+ long st_ctime; /* Time of last status change. */
+ unsigned long st_ctime_nsec;
+ unsigned int __unused4;
+ unsigned int __unused5;
+ };
+
+#endif
diff --git a/usr/include/arch/arm64/klibc/asmmacros.h b/usr/include/arch/arm64/klibc/asmmacros.h
new file mode 100644
index 0000000..c298f66
--- /dev/null
+++ b/usr/include/arch/arm64/klibc/asmmacros.h
@@ -0,0 +1,11 @@
+/*
+ * usr/include/arch/arm64/klibc/asmmacros.h
+ *
+ * Assemb...
2013 Oct 09
0
[PATCH 1/1] Porting klibc to AArch64
...long st_mtime; /* Time of last modification. */
+ unsigned long st_mtime_nsec;
+ long st_ctime; /* Time of last status change.
*/
+ unsigned long st_ctime_nsec;
+ unsigned int __unused4;
+ unsigned int __unused5;
+ };
-#endif
+#endif
diff --git a/usr/include/sys/stat.h b/usr/include/sys/stat.h
index 4850429..4e3c170 100644
--- a/usr/include/sys/stat.h
+++ b/usr/include/sys/stat.h
@@ -56,12 +56,6 @@
#endif
-#ifdef _STATBUF_ST_NSEC
- /* struct stat has struct timespec instead of time_t */
-# define st_...
2013 Aug 02
3
[PATCH trivial] include: uapi: standard all files' macro prefix and suffix, excluding "linux/" sub-directory
...c/msgbuf.h
+++ b/include/uapi/asm-generic/msgbuf.h
@@ -1,5 +1,5 @@
-#ifndef __ASM_GENERIC_MSGBUF_H
-#define __ASM_GENERIC_MSGBUF_H
+#ifndef _UAPI_ASM_GENERIC_MSGBUF_H
+#define _UAPI_ASM_GENERIC_MSGBUF_H
#include <asm/bitsperlong.h>
/*
@@ -44,4 +44,4 @@ struct msqid64_ds {
unsigned long __unused5;
};
-#endif /* __ASM_GENERIC_MSGBUF_H */
+#endif /* _UAPI_ASM_GENERIC_MSGBUF_H */
diff --git a/include/uapi/asm-generic/param.h b/include/uapi/asm-generic/param.h
index 5becc84..2032540 100644
--- a/include/uapi/asm-generic/param.h
+++ b/include/uapi/asm-generic/param.h
@@ -1,5 +1,5 @@
-#ifndef...
2013 Aug 02
3
[PATCH trivial] include: uapi: standard all files' macro prefix and suffix, excluding "linux/" sub-directory
...c/msgbuf.h
+++ b/include/uapi/asm-generic/msgbuf.h
@@ -1,5 +1,5 @@
-#ifndef __ASM_GENERIC_MSGBUF_H
-#define __ASM_GENERIC_MSGBUF_H
+#ifndef _UAPI_ASM_GENERIC_MSGBUF_H
+#define _UAPI_ASM_GENERIC_MSGBUF_H
#include <asm/bitsperlong.h>
/*
@@ -44,4 +44,4 @@ struct msqid64_ds {
unsigned long __unused5;
};
-#endif /* __ASM_GENERIC_MSGBUF_H */
+#endif /* _UAPI_ASM_GENERIC_MSGBUF_H */
diff --git a/include/uapi/asm-generic/param.h b/include/uapi/asm-generic/param.h
index 5becc84..2032540 100644
--- a/include/uapi/asm-generic/param.h
+++ b/include/uapi/asm-generic/param.h
@@ -1,5 +1,5 @@
-#ifndef...
2013 Aug 02
3
[PATCH trivial] include: uapi: standard all files' macro prefix and suffix, excluding "linux/" sub-directory
...c/msgbuf.h
+++ b/include/uapi/asm-generic/msgbuf.h
@@ -1,5 +1,5 @@
-#ifndef __ASM_GENERIC_MSGBUF_H
-#define __ASM_GENERIC_MSGBUF_H
+#ifndef _UAPI_ASM_GENERIC_MSGBUF_H
+#define _UAPI_ASM_GENERIC_MSGBUF_H
#include <asm/bitsperlong.h>
/*
@@ -44,4 +44,4 @@ struct msqid64_ds {
unsigned long __unused5;
};
-#endif /* __ASM_GENERIC_MSGBUF_H */
+#endif /* _UAPI_ASM_GENERIC_MSGBUF_H */
diff --git a/include/uapi/asm-generic/param.h b/include/uapi/asm-generic/param.h
index 5becc84..2032540 100644
--- a/include/uapi/asm-generic/param.h
+++ b/include/uapi/asm-generic/param.h
@@ -1,5 +1,5 @@
-#ifndef...
2013 Nov 11
5
[PATCH V2 0/3] Introduce arm64 support
Hello,
Here is V2 of the arm64 support for klibc patch set.
Notable changes since the original series:
* fp regs dropped from setjmp/longjmp
* chmod, lstat and stat re-implemented with *at functions.
* open64 merged into open.
As with the original, this series is to be applied against the latest
klibc, just after
25a66fa README.klibc: update build information
V2 has been tested on x86_64
2013 Nov 08
9
[PATCH 0/3] Introduce arm64 support
Hello,
This series introduces arm64 support to klibc.
I've rebased the work from Neil Williams and Anil Singhar into the
following three patches. Most of the code changes are due to new
syscall implementations being needed for arm64 as a only a minimal set
of syscalls are defined in the arm64 kernel.
This series is to be applied against the latest klibc, just after
25a66fa README.klibc:
2006 Jun 26
0
[klibc 35/43] sparc support for klibc
...ed int st_gid;
+
+ __stdev64 (st_rdev);
+
+ unsigned char __pad3[8];
+
+ long long st_size;
+ unsigned int st_blksize;
+
+ unsigned char __pad4[8];
+ unsigned int st_blocks;
+
+ struct timespec st_atim;
+ struct timespec st_mtim;
+ struct timespec st_ctim;
+
+ unsigned int __unused4;
+ unsigned int __unused5;
+};
+
+#endif
diff --git a/usr/include/arch/sparc/klibc/archsys.h b/usr/include/arch/sparc/klibc/archsys.h
new file mode 100644
index 0000000..a6ca545
--- /dev/null
+++ b/usr/include/arch/sparc/klibc/archsys.h
@@ -0,0 +1,10 @@
+/*
+ * arch/sparc/include/klibc/archsys.h
+ *
+ * Architecture-specifi...
2006 Jun 28
35
[klibc 00/31] klibc as a historyless patchset (updated and reorganized)
I have updated the klibc patchset based on feedback received. In
particular, the patchset has been reorganized so as not to break
git-bisect.
Additionally, this updates the patch base to 2.6.17-git12
(d38b69689c349f35502b92e20dafb30c62d49d63) and klibc 1.4.8; the main
difference on the klibc side is removal of obsolete code.
This is also available as a git tree at:
2003 Dec 01
0
No subject
...5, __pad1 = 0, st_ino = 32611, st_mode = 33206, st_nlink = 1, st_uid = 507,
st_gid = 507, st_rdev = 0, __pad2 = 0, st_size = 50688, st_blksize = 4096, st_blocks = 112,
st_atime = 994072899, __unused1 = 0, st_mtime = 993039758, __unused2 = 0, st_ctime = 994072898,
__unused3 = 0, __unused4 = 0, __unused5 = 0}
bad_path = 0
access_mode = 0
action = 1
ecode = 0
user = {conn = 0x81ec938, vuid = 100, uid = 507, gid = 507, ngroups = 1, groups = 0x81eb4e8,
nt_user_token = 0x81eb4f8}
user_name = "eelco", '\000' <repeats 11 times>, "'\000\000\000uF\b@", '\00...
diff --git a/usr/include/arch/ppc/klibc/archsys.h b/usr/include/arch/ppc/klibc/archsys.h
new file mode 100644
index 0000000..24752da
--- /dev/null
+++ b/usr/include/arch/ppc/klibc/archsys.h
@@ -0,0 +1,61 @@
+/*
+ * arch/ppc/include/klibc/archsys.h
+ *
+ * Architecture-specific syscal...
2015 May 18
5
kernel/libc uapi changes for y2038
...define __kernel_stat stat
+#endif
#define STAT_HAVE_NSEC 1
@@ -26,7 +33,7 @@ struct __old_kernel_stat {
};
#endif /* !__powerpc64__ */
-struct stat {
+struct __old_kernel_stat2 {
unsigned long st_dev;
ino_t st_ino;
#ifdef __powerpc64__
@@ -78,7 +85,7 @@ struct stat64 {
unsigned int __unused5;
};
/* this matches the powerpc64 'struct stat' for compat tasks */
struct __kernel_stat {
unsigned long long st_dev;
unsigned long long st_ino;
@@ -101,6 +107,5 @@ struct __kernel_stat {
unsig...
2006 Jun 26
0
[klibc 32/43] ppc64 support for klibc
...off_t st_size;
+ unsigned long st_blksize;
+ unsigned long st_blocks;
+ struct timespec st_atim; /* Time of last access. */
+ struct timespec st_mtim; /* Time of last modification. */
+ struct timespec st_ctim; /* Time of last status change. */
+ unsigned long __unused4;
+ unsigned long __unused5;
+ unsigned long __unused6;
+};
+
+#endif
@@ -78,7 +85,7 @@ struct stat64 {
unsigned int __unused5;
};
-/* this matches the powerpc64 'struct stat' for compat tasks */
+/* this matches the powerpc64 'struct __old_kernel_stat2' for compat tasks */
struct __kernel_stat {
unsigned long long st_dev;